Enumeration
AyatanaAppIndicatorGlibIndicatorStatus
since: 2.0
Description
These are the states that the indicator can be on in
the user’s panel. The indicator by default starts
in the state APP_INDICATOR_STATUS_PASSIVE and can be
shown by setting it to APP_INDICATOR_STATUS_ACTIVE.
Available since: 2.0
Members
APP_INDICATOR_STATUS_PASSIVE-
The indicator should not be shown to the user.
- Value:
0 - Nickname:
None - Available since: 2.0
- Value:
APP_INDICATOR_STATUS_ACTIVE-
The indicator should be shown in it’s default state.
- Value:
1 - Nickname:
None - Available since: 2.0
- Value:
APP_INDICATOR_STATUS_ATTENTION-
The indicator should show it’s attention icon.
- Value:
2 - Nickname:
None - Available since: 2.0
- Value: