Enumeration
AyatanaAppIndicatorGlibIndicatorCategory
since: 2.0
Description
The category provides grouping for the indicators so that users can find indicators that are similar together.
Available since: 2.0
Members
APP_INDICATOR_CATEGORY_APPLICATION_STATUS-
The indicator is used to display the status of the application.
- Value:
0 - Nickname:
None - Available since: 2.0
- Value:
APP_INDICATOR_CATEGORY_COMMUNICATIONS-
The application is used for communication with other people.
- Value:
1 - Nickname:
None - Available since: 2.0
- Value:
APP_INDICATOR_CATEGORY_SYSTEM_SERVICES-
A system indicator relating to something in the user’s system.
- Value:
2 - Nickname:
None - Available since: 2.0
- Value:
APP_INDICATOR_CATEGORY_HARDWARE-
An indicator relating to the user’s hardware.
- Value:
3 - Nickname:
None - Available since: 2.0
- Value:
APP_INDICATOR_CATEGORY_OTHER-
Something not defined in this enum, please don’t use unless you really need it.
- Value:
4 - Nickname:
None - Available since: 2.0
- Value: